@@ -4,5 +4,7 @@ from .automl_batch import *
 from .automl_cloudwatch import *
 from .automl_cognito import *
 from .automl_rds import *
+from .automl_ec2 import *
+from .automl_ecs import *
 from .automl_s3 import *
 from .automlClient import APIUser, private_upload_dataset, make_lst
